# Installation

The MiniAV CLI is available through [PyPI](https://pypi.org/project/miniav) and can be installed with the following command:

```bash
pip install miniav
```

[myst-markdown]: https://myst-parser.readthedocs.io/en/latest/
[restructuredtext]: https://docutils.sourceforge.io/docs/user/rst/quickref.html
